@@ -87,6 +87,7 @@ int parse_rfc_kwargs( PyObject* kwargs, Py_ssize_t len, Rainflow *rf, Rainflow::
 
         PyObject *key, *value;
         Py_ssize_t pos = 0;
+        bool wl_k2_set = false;
 
         // Iterate over keys
         while( PyDict_Next( wl, &pos, &key, &value ) )
@@ -112,17 +113,19 @@ int parse_rfc_kwargs( PyObject* kwargs, Py_ssize_t len, Rainflow *rf, Rainflow::
             else if( PyUnicode_CompareWithASCIIString( key, "k2" ) == 0 )
             {
                 wl_k2 = fabs( PyFloat_AsDouble( value ) );
+                wl_k2_set = true;
             }
             else
             {
-                PyErr_Format( PyExc_RuntimeError, "Wrong key used in wl dict: %O", key );
+                PyErr_Format( PyExc_RuntimeError, "Wrong key used in wl dict: `%S`", key );
                 return 0;
             }
         }
 
-        if( wl_k2 < 0 ) wl_k2 = wl_k;
-        if( hysteresis < 0 ) hysteresis = class_width;
+        if( !wl_k2_set ) wl_k2 = wl_k;
     }
+    
+    if( hysteresis < 0 ) hysteresis = class_width;
 
     if( !rf->init( class_count, class_width, class_offset, hysteresis, (Rainflow::rfc_flags_e)flags ) )
     {
@@ -283,6 +286,38 @@ int do_rainflow( Rainflow *rf, npy_double *data, Py_ssize_t len, Rainflow::rfc_r
 
     residuum_raw = rfc_residuum_vec( residuum, residuum + residuum_len );
 
+    // (With regard to finalize_res_repeated() in rainflow.c, remove pending cycle)
+    if( residuum_raw.size() >= 4 )
+    {
+        size_t idx = residuum_raw.size() - 4;
+
+        unsigned A = residuum_raw[idx+0].cls;
+        unsigned B = residuum_raw[idx+1].cls;
+        unsigned C = residuum_raw[idx+2].cls;
+        unsigned D = residuum_raw[idx+3].cls;
+
+        if( B > C )
+        {
+            unsigned temp = B;
+            B = C;
+            C = temp;
+        }
+
+        if( A > D )
+        {
+            unsigned temp = A;
+            A = D;
+            D = temp;
+        }
+
+        /* Check for closed cycles [3] */
+        if( A <= B && C <= D )
+        {
+            // Remove points B and C
+            residuum_raw.erase(residuum_raw.begin() + 1, residuum_raw.begin() + 3);
+        }
+    }
+
     if( !rf->finalize( res_method ) ) goto fail;
 
     return 1;
